@@ -1,16 +1,17 @@
 from .agnn_conv import AGNNConv
-from .appnp import APPNP
+from .appnp_conv import APPNPConv
 from .arma_conv import ARMAConv
 from .cheb_conv import ChebConv
 from .crystal_conv import CrystalConv
 from .diffusion_conv import DiffusionConv
-from .ecc_conv import EdgeConditionedConv
+from .ecc_conv import ECCConv
 from .edge_conv import EdgeConv
+from .gat_conv import GATConv
 from .gated_graph_conv import GatedGraphConv
+from .gcn_conv import GCNConv
+from .gcs_conv import GCSConv
+from .general_conv import GeneralConv
 from .gin_conv import GINConv
-from .graph_attention import GraphAttention
-from .graph_conv import GraphConv
-from .graph_conv_skip import GraphConvSkip
 from .graphsage_conv import GraphSageConv
 from .message_passing import MessagePassing
 from .tag_conv import TAGConv
